@@ -1,21 +1,24 @@
-# -----------------------------------------------------------
-# Calculates higher order crossings of a singal, referred
-# from the paper "Discrimination analysis of discontinuous
-# breath sounds using higher-order crossings" authored by
-# L. J. Hadjileontiadis
-#
-# (C) 2020 Aditya Srivastava, Mumbai, India
-#
-# email adityasrivastava301199@gmail.com
-# -----------------------------------------------------------
+"""
+Calculates higher order crossings of a singal.
 
+Referred from the paper "Discrimination analysis of
+discontinuous breath sounds using higher-order crossings"
+Authored by, L. J. Hadjileontiadis
+
+(C) 2020 Aditya Srivastava, Mumbai, India
+GNU General Public License v3 (GPLv3)
+email adityasrivastava301199@gmail.com
+"""
 import numpy
 
 
 class PyHOC:
+    """Contains the function/s which calculate hoc of a signal."""
 
     def sequence(self, signal, k):
         """
+        Calculate Higher Order Crossings of a Singal.
+
         Inputs:
         signal: 1D numpy array of input signal or sequence
         k : number of terms to be included in HOC sequence
@@ -24,7 +27,6 @@ class PyHOC:
         nzc: 1D numpy array of HOCs corresponding to sequence
              of high-pass filters
         """
-
         nzc = []    # list to store results
         try:
 
